@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.3.22
+# Version   : 0.3.24
 
 from operator import contains
 import  numpy                   as      np
@@ -644,6 +644,8 @@ class AFM:
 
         self.contact_point = np.zeros(self.z_approach.shape[1])
         self.indent_depth = np.zeros(self.z_approach.shape[1])
+
+        prev_intercept = 0
         
         for i in range(0, self.z_approach.shape[1]):
             _approach = self.approach[:,i]
@@ -667,15 +669,15 @@ class AFM:
                     self.z_withdraw[:,i] = self.z_withdraw[:,i] - intercept
                     self.contact_point[i] = intercept
                     self.indent_depth[i] = next(n for n in self.z_approach[:,i] if n == n)
+                    prev_intercept = intercept
 
             except:
                 print('WARNING: Could not locate contact point for curve number ', i, '. Consider checking baseline alignment. Contact point from previous curve will be used instead.')
 
-                if np.isnan(intercept) == False:
-                    self.z_approach[:,i] = self.z_approach[:,i] - intercept
-                    self.z_withdraw[:,i] = self.z_withdraw[:,i] - intercept
-                    self.contact_point[i] = intercept
-                    self.indent_depth[i] = next(n for n in self.z_approach[:,i] if n == n)
+                self.z_approach[:,i] = self.z_approach[:,i] - prev_intercept
+                self.z_withdraw[:,i] = self.z_withdraw[:,i] - prev_intercept
+                self.contact_point[i] = prev_intercept
+                self.indent_depth[i] = next(n for n in self.z_approach[:,i] if n == n)
 
     def adjust_tip_position(
         self
@@ -703,7 +705,9 @@ class AFM:
             self.indent_depth[i] = next(n for n in self.z_approach[:,i] if n == n)
 
     def snap_in_distance(
-        self
+        self,
+        rolling_points = 5,
+        gradient_tolerance = 0.05
     ):
         '''
         Calculate distance from surface at which snap in begins.
@@ -715,7 +719,11 @@ class AFM:
             f = self.approach[:,i]
             d = self.z_approach[:,i]
 
-            snap_distance[i] = d[self.knee_point(f, d)]
+            try:
+                snap_distance[i] = d[self.knee_point(f, d, rolling_points, gradient_tolerance)]
+            except:
+                snap_distance[i] = np.nan
+
 
         self.snap_dist = snap_distance
 
@@ -730,8 +738,8 @@ class AFM:
     def knee_point(self,
         X,
         Y,
-        rolling_points = 5,
-        gradient_tolerance = 0.05
+        rolling_points,
+        gradient_tolerance
     ):
         grad = np.zeros([len(Y),1])
 
@@ -1522,8 +1530,8 @@ class AFM:
             _nid = ns.read(self.file_name)
 
             if auto_cell == True:
-                x_cells = _nid.param.SpecMap.maps[0][4]
-                y_cells = _nid.param.SpecMap.maps[0][5]
+                x_cells = int(_nid.param.SpecMap.maps[0][4])
+                y_cells = int(_nid.param.SpecMap.maps[0][5])
                 x_scale = np.asarray(_nid.param['Header Dump']['DataSet\Parameters\Imaging']['ScanRange'].split('[')[1].split(',')[0], dtype=float) * 1e6
                 y_scale = np.asarray(_nid.param['Header Dump']['DataSet\Parameters\Imaging']['ScanRange'].split('[')[1].split(',')[1], dtype=float) * 1e6
 
@@ -1671,8 +1679,8 @@ class AFM:
                     showlegend = False,
                     width = 700, height = 700,
                     autosize = False,
-                    xaxis_title="X Position ($\mu$m)",
-                    yaxis_title="Y Position ($\mu$m)")
+                    xaxis_title="X Position (μm)",
+                    yaxis_title="Y Position (μm)")
 
                 fig.update_layout(
                     xaxis = dict(
@@ -1705,8 +1713,8 @@ class AFM:
                                 colorbar=dict(title=plt_title)))
 
                 fig.update_layout(scene = dict(
-                                xaxis_title='X Position ($\mu$m)',
-                                yaxis_title='Y Position ($\mu$m)',
+                                xaxis_title='X Position (μm)',
+                                yaxis_title='Y Position (μm)',
                                 zaxis_title='Z Position (nm)'),
                                 margin=dict(r=20, b=10, l=10, t=10))
 
